@@ -69,9 +69,7 @@ int main(int argc, char** argv)
   
     QCommandLineParser parser;
     
-    parser.addVersionOption();
-    parser.addHelpOption();
-    parser.addOption(QCommandLineOption(QStringList() << QLatin1String("!+[URL]"), i18n("URL of a Naval Battle game server to connect to after startup")));
+    parser.addPositionalArgument(i18n("[URL]"), i18n("URL of a Naval Battle game server to connect to after startup"));
 
     aboutData.setupCommandLine(&parser);
     parser.process(app);
